'''
Author: BHM-Bob 2262029386@qq.com
Date: 2022-11-01 22:16:49
LastEditors: BHM-Bob
LastEditTime: 2023-04-06 21:34:17
Description: 
'''
from . import base, file, plot, web, dl_torch, stats
from .__version__ import (
    __author__,
    __author_email__,
    __build__,
    __description__,
    __license__,
    __title__,
    __version__,
    __url__,
)

# def main():
#     pass
"""
var naming:

constant : CONSTANT_VAR_NAME
variable : var_name
func : func_name
global var: globalVarName
class : ClassName
"""